API Reference
============

This section provides detailed documentation for the aiopromql API.

Clients
-------

.. automodule:: aiopromql.client
   :members:
   :undoc-members:
   :show-inheritance:

Models
------

Core Models
~~~~~~~~~~

.. automodule:: aiopromql.models.core
   :members:
   :undoc-members:
   :show-inheritance:

Prometheus Models
~~~~~~~~~~~~~~~

.. automodule:: aiopromql.models.prometheus
   :members:
   :undoc-members:
   :show-inheritance:

Package
-------

.. automodule:: aiopromql
   :members:
   :undoc-members:
   :show-inheritance: 